$(document).ready(function(){
    // установим локализованные строки
    setLocaleStrings();

    // сделать запрос на получение информации
    chrome.runtime.sendMessage({
        type: 'assistant/get-info',
        cache_time : 60 * 1000 // 1 минута кэша
    }, function(data) {

        if (!data.success) {
            // нет подписки или ещё чего, информация в data.error
            $('#loading').hide();
            $('#error').text(data.error).show();
            return;
        }

        $('#updated').val(data.settings.updated).prop('disabled', false);

        // получим текущую активную страницу, синхронно никак
        chrome.tabs.query({active: true, currentWindow: true}, function([tab]) {

            let url = document.createElement('a');
            url.href = tab.url;

            let site_script = data.scripts.find(e => e.domain == url.hostname);

            if (site_script) {
                // для текущего сайта есть скрипт. Если доспут еже есть, то ставим кнопку отмены, если нет, то  кнопку запроса
                updatePremissionButton();
            } else {
                // для текущего сайта нет скрипта
                $('#loading').hide();
                $('#get_premission .get_premission__text').text(chrome.i18n.getMessage("noScriptFor") + url.hostname);
                $('#get_premission').show();
            }

        });

    });

    // обновить состояние кнопки
    function updatePremissionButton() {
        // получим текущую активную страницу, синхронно никак
        chrome.tabs.query({active: true, currentWindow: true}, function([tab]) {
            let url = document.createElement('a');
            url.href = tab.url;

            chrome.permissions.contains({
                origins: [`${url.protocol}//${url.hostname}/`]
            }, function(result) {

                $('#loading').hide();

                if (result) {
                    // доступ есть, сразу включаем скрипт
                    chrome.runtime.sendMessage({
                        type: 'assistant/execute-script',
                        tab: tab
                    }, function() {});

                    $('#get_premission')
                        .show()
                        .removeClass('green')
                        .addClass('red')
                        .attr('access', 'true')
                        .find('.get_premission__text')
                        .text(chrome.i18n.getMessage("turnOff") + url.hostname)
                        .parent()
                        .find('.get_premission__icon')
                        .html('<div class="arrow-left"></div><i class="fa fa-trash-o" aria-hidden="true"></i>');
                } else {
                    // доступа нет
                    $('#get_premission')
                        .show()
                        .removeClass('red')
                        .addClass('green')
                        .attr('access', 'false')
                        .find('.get_premission__text')
                        .text(chrome.i18n.getMessage("turnOn") + url.hostname)
                        .parent()
                        .find('.get_premission__icon')
                        .html('<div class="arrow-left"></div><i class="fa fa-check" aria-hidden="true"></i>');
                }

            });
        });

    }

    // запросить у пользователя доступ к текущей странице
    $('body').on('click', '#get_premission[access]', function(){

        let remove = $(this).attr('access') === 'true' ? true : false;

        chrome.tabs.query({active: true, currentWindow: true}, function([tab]) {

            let url = document.createElement('a');
            url.href = tab.url;

            if (remove) {
                chrome.permissions.remove({
                    origins: [`${url.protocol}//${url.hostname}/`]
                }, function(removed) {
                    updatePremissionButton();
                });
            } else {
                chrome.permissions.request({
                    origins: [`${url.protocol}//${url.hostname}/`]
                }, function(granted) {
                    updatePremissionButton();
                });
            }


        });

    });

    $('#updated').change(function(){

        chrome.runtime.sendMessage({
            type: 'settings/save',
            option : "updated",
            value : Number($(this).val()) || 60
        }, function() {});

    });

});

// установим локализованные строки
function setLocaleStrings() {
    $('label[for="updated"]').text( chrome.i18n.getMessage("labelTimeFilter") );
    $('#updated').attr('placeholder', chrome.i18n.getMessage("updatedPlaceholder") );
}